id must be of an osm_points, osm_lines, or
osm_polygons object. osm_multipolygons returns any multipolygon
object(s) which contain the object specified by id.
osm_multipolygons(dat, id)
| dat | An object of class osmdata |
|---|---|
| id | OSM identification of one or more objects for which multipolygons are to be extracted |
An sf Simple Features Collection of multipolygons
if (FALSE) { # find all multipolygons which contain the single polygon called # "Chiswick Eyot" (which is an island). dat <- opq ("London UK") add_osm_feature (key="name", value="Thames", exact=FALSE) id <- rownames (dat$osm_polygons [which (dat$osm_polygons$name == "Chiswick Eyot"),]) osm_multipolygons (dat, id) # That multipolygon is the Thames itself, but note that nrow (dat$osm_multipolygons) # = 14 multipolygon objects nrow (osm_multipolygons (dat, id)) # = 1 - the main Thames multipolygon }