If id is of a point object, osm_polygons will return all
polygons containing that point. If id is of a line or polygon object,
osm_polygons will return all polygons which intersect the given line
or polygon.
osm_polygons(dat, id)
| dat | An object of class osmdata |
|---|---|
| id | OSM identification of one or more objects for which polygons are to be extracted |
An sf Simple Features Collection of polygons