R/get-osmdata.R
osmdata_pbf.RdReturn an OSM Overpass query in PBF (Protocol Buffer Format).
osmdata_pbf(q, filename, quiet = TRUE)
| q | An object of class |
|---|---|
| filename | If given, OSM data are saved to the named file |
| quiet | suppress status messages. |
An binary Protocol Buffer Format (PBF) object.
This function is experimental, and osmdata can currently NOT do anything with PBF files.
if (FALSE) { q <- opq ("hampi india") q <- add_osm_feature (q, key="historic", value="ruins") osmdata_pdf (q, filename="hampi.pbf") }