Convert an osmdata query of class opq to a character string query to be submitted to the overpass API.
opq_string(opq)
| opq | An |
|---|
Character string to be submitted to the overpass API
#> [1] "[out:xml][timeout:25];\n(\n node (15.3158,76.4410201,15.3558,76.4810201);\n way (15.3158,76.4410201,15.3558,76.4810201);\n relation (15.3158,76.4410201,15.3558,76.4810201);\n);\n(._;>;);\nout body;"